@@ -54,12 +54,11 @@ rcube_webmail.prototype.sieverules_mouse_up = function(e) {
 
 		if (rcmail.env.sieverules_last_target == 'end') {
 			var _dst = rcmail.sieverules_list.rows.length;
-			$(rcmail.gui_objects.sieverules_list).removeClass('droptargetend');
+			$(rcmail.gui_objects.sieverules_list).children('tbody').children('tr:last').removeClass('droptargetend');
 		}
 		else {
 			var _dst = rcmail.env.sieverules_last_target.substr(6);
-			$('#' + rcmail.env.sieverules_last_target + ' td:eq(0)').removeClass('droptarget');
-			$('#' + rcmail.env.sieverules_last_target + ' td:eq(1)').removeClass('droptarget');
+			$('#' + rcmail.env.sieverules_last_target).removeClass('droptarget');
 		}
 
 		rcmail.command('plugin.sieverules.move', { source:_src, dest:_dst });
@@ -111,11 +110,11 @@ rcube_webmail.prototype.sieverules_drag_move = function(e) {
 
 		// if mouse pointer is outside of folderlist
 		if (mouse.x < pos.x1 || mouse.x >= pos.x2 || mouse.y < pos.y1 || mouse.y >= pos.y2) {
-			$(rcmail.gui_objects.sieverules_list).removeClass('droptargetend');
+			$(rcmail.gui_objects.sieverules_list).children('tbody').children('tr:last').removeClass('droptargetend');
 			rcmail.env.sieverules_last_target = null;
 		}
 		else {
-			$(rcmail.gui_objects.sieverules_list).addClass('droptargetend');
+			$(rcmail.gui_objects.sieverules_list).children('tbody').children('tr:last').addClass('droptargetend');
 			rcmail.env.sieverules_last_target = 'end';
 		}
 
@@ -123,15 +122,13 @@ rcube_webmail.prototype.sieverules_drag_move = function(e) {
 		for (var k in rcmail.env.sieverules_coords) {
 			pos = rcmail.env.sieverules_coords[k];
 			if (mouse.x >= pos.x1 && mouse.x < pos.x2 && mouse.y >= pos.y1 && mouse.y < pos.y2) {
-				$(rcmail.gui_objects.sieverules_list).removeClass('droptargetend');
-				$('#' + k + ' td:eq(0)').addClass('droptarget');
-				$('#' + k + ' td:eq(1)').addClass('droptarget');
+				$(rcmail.gui_objects.sieverules_list).children('tbody').children('tr:last').removeClass('droptargetend');
+				$('#' + k).addClass('droptarget');
 				rcmail.env.sieverules_last_target = k;
 				rcmail.env.sieverules_coords[k].on = 1;
 			}
 			else if (pos.on) {
-				$('#' + k + ' td:eq(0)').removeClass('droptarget');
-				$('#' + k + ' td:eq(1)').removeClass('droptarget');
+				$('#' + k).removeClass('droptarget');
 				rcmail.env.sieverules_last_target = null;
 				rcmail.env.sieverules_coords[k].on = 0;
 			}
@@ -148,17 +145,16 @@ rcube_webmail.prototype.sieverules_drag_end = function(e) {
 	if (rcmail.gui_objects.sieverules_list && rcmail.env.sieverules_coords) {
 		for (var k in rcmail.env.sieverules_coords) {
 			if (rcmail.env.sieverules_coords[k].on) {
-				$('#' + k + ' td:eq(0)').removeClass('droptarget');
-				$('#' + k + ' td:eq(1)').removeClass('droptarget');
+				$('#' + k).removeClass('droptarget');
 			}
 		}
 	}
 
-	$(rcmail.gui_objects.sieverules_list).removeClass('droptargetend');
+	$(rcmail.gui_objects.sieverules_list).children('tbody').children('tr:last').removeClass('droptargetend');
 };
 
 rcube_webmail.prototype.sieverules_load = function(id, action) {
-	if (action == 'plugin.sieverules.edit' && (!id || id==rcmail.env.iid))
+	if (action == 'plugin.sieverules.edit' && (!id || id == rcmail.env.iid))
 		return false;
 
 	var add_url = '';
@@ -177,6 +173,19 @@ rcube_webmail.prototype.sieverules_load = function(id, action) {
 	return true;
 }
 
+rcube_webmail.prototype.sieverules_ready = function(id) {
+	if (id.substring(0, 2) != 'ex')
+		rcmail.enable_command('plugin.sieverules.delete', true);
+
+	if (rcmail.sieverules_examples)
+		rcmail.sieverules_examples.clear_selection();
+
+	rcmail.sieverules_list.highlight_row(id);
+	rcmail.env.iid = id;
+
+	return true;
+}
+
 rcube_webmail.prototype.sieverules_update_list = function(action, param1, param2, param3, param4) {
 	var sid = rcmail.sieverules_list.get_single_selection();
 	var selection;
@@ -494,6 +503,7 @@ rcube_webmail.prototype.sieverules_datepart_select = function(sel) {
 	var obj = document.getElementsByName('_datepart[]')[eidx];
 	var opr = document.getElementsByName('_operator[]')[eidx];
 	var target_obj = $("input[name='_target[]']")[eidx];
+	$(target_obj).datepicker("destroy");
 	$(target_obj).unmask();
 
 	if (obj.value == 'date')
@@ -580,6 +590,13 @@ rcube_webmail.prototype.sieverules_action_select = function(sel) {
 		document.getElementsByName('_reject[]')[idx].style.display = '';
 	else if (obj.value == 'vacation') {
 		document.getElementsByName('_day[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = '';
+
+		if (rcmail.env.sieverules_htmleditor == 1) {
+			rowid = document.getElementsByName('_msg[]')[idx].id.replace('rcmfd_sievevacmag_', '');
+			document.getElementById('rcmfd_sievevachtmlcb_' + rowid).checked = true;
+			rcmail.sieverules_toggle_vac_html(document.getElementById('rcmfd_sievevachtmlcb_' + rowid), rowid, 'rcmfd_sievevacmag_' + rowid);
+		}
+
 		rcmail.enable_sig(document.getElementsByName('_vacfrom[]')[idx]);
 	}
 	else if (obj.value == 'notify' || obj.value == 'enotify')
@@ -739,7 +756,7 @@ rcube_webmail.prototype.sieverules_add_ruleset = function(val, text) {
 
 rcube_webmail.prototype.sieverules_disable_ruleset_options = function() {
 	$('#rulelist').attr("disabled", "disabled");
-	rcmail.enable_command('plugin.sieverules.ruleset_dialog', 'plugin.sieverules.activate_ruleset', 'plugin.sieverules.del_ruleset', false)
+	rcmail.enable_command('plugin.sieverules.ruleset_dialog', 'plugin.sieverules.activate_ruleset', 'plugin.sieverules.del_ruleset', false);
 }
 
 rcube_webmail.prototype.sieverulesdialog_submit = function() {
@@ -797,7 +814,7 @@ $(document).ready(function() {
 	if (window.rcmail) {
 		rcmail.addEventListener('init', function(evt) {
 			if (rcmail.env.action == 'plugin.sieverules.add' || rcmail.env.action == 'plugin.sieverules.edit' || rcmail.env.action == 'plugin.sieverules.setup' || rcmail.env.action == 'plugin.sieverules.advanced')
-				var tab = $('<span>').attr('id', 'settingstabpluginsieverules').addClass('tablink-selected');
+				var tab = $('<span>').attr('id', 'settingstabpluginsieverules').addClass('tablink selected');
 			else
 				var tab = $('<span>').attr('id', 'settingstabpluginsieverules').addClass('tablink');
 
@@ -809,6 +826,10 @@ $(document).ready(function() {
 			if ((rcmail.env.action == 'plugin.sieverules' || rcmail.env.action == 'plugin.sieverules.advanced') && !rcmail.env.sieveruleserror) {
 				if (rcmail.gui_objects.sieverules_list) {
 					rcmail.sieverules_list = new rcube_list_widget(rcmail.gui_objects.sieverules_list, {multiselect:false, draggable:true, keyboard:true});
+
+					// override blur function to prevent current rule being deselected
+					rcmail.sieverules_list.blur = function() {}
+
 					rcmail.sieverules_list.addEventListener('select', function(o) { rcmail.sieverules_select(o); });
 					rcmail.sieverules_list.addEventListener('keypress', function(o) { rcmail.sieverules_keypress(o); });
 					rcmail.sieverules_list.addEventListener('dragstart', function(o) { rcmail.sieverules_drag_start(o); });
@@ -854,6 +875,9 @@ $(document).ready(function() {
 					rcmail.register_command('plugin.sieverules.add', function(id) {
 							if (rcmail.sieverules_examples) rcmail.sieverules_examples.clear_selection();
 							rcmail.sieverules_list.clear_selection();
+							rcmail.env.iid = null;
+							rcmail.enable_command('plugin.sieverules.delete', false);
+
 							var add_url = '';
 
 							var target = window;
@@ -877,26 +901,30 @@ $(document).ready(function() {
 					rcube_find_object('sieverulesrsdialog_name').value = '';
 
 					if (props == 'rename_ruleset') {
-						rcube_find_object('sieverulesrsdialog_edit').style.display = '';
+						//rcube_find_object('sieverulesrsdialog_edit').style.display = '';
+						boxtitle = rcube_find_object('sieverulesrsdialog_edit').innerHTML;
 						rcube_find_object('sieverulesrsdialog_input').style.display = '';
 						rcube_find_object('sieverulesrsdialog_name').value = rcmail.env.ruleset;
 					}
 					else if (props == 'copyto_ruleset') {
-						rcube_find_object('sieverulesrsdialog_copyto').style.display = '';
+						//rcube_find_object('sieverulesrsdialog_copyto').style.display = '';
+						boxtitle = rcube_find_object('sieverulesrsdialog_copyto').innerHTML;
 						rcube_find_object('sieverulesrsdialog_select').style.display = '';
 					}
 					else if (props == 'copyfrom_ruleset') {
-						rcube_find_object('sieverulesrsdialog_copyfrom').style.display = '';
+						//rcube_find_object('sieverulesrsdialog_copyfrom').style.display = '';
+						boxtitle = rcube_find_object('sieverulesrsdialog_copyfrom').innerHTML;
 						rcube_find_object('sieverulesrsdialog_select').style.display = '';
 					}
 					else {
-						rcube_find_object('sieverulesrsdialog_add').style.display = '';
+						//rcube_find_object('sieverulesrsdialog_add').style.display = '';
+						boxtitle = rcube_find_object('sieverulesrsdialog_add').innerHTML;
 						rcube_find_object('sieverulesrsdialog_input').style.display = '';
 					}
 
 					rcube_find_object('sieverulesrsdialog_action').value = props;
 
-					$('#sieverulesrsdialog').dialog({ width: 512, resizable: false, modal: true });
+					$('#sieverulesrsdialog').dialog({ title: boxtitle, width: 512, resizable: false, modal: true });
 				}, true);
 
 				rcmail.register_command('plugin.sieverules.activate_ruleset', function(props, obj) {
@@ -936,6 +964,22 @@ $(document).ready(function() {
 					rcmail.sieverules_adveditor(chkbox);
 				}, true);
 
+				rcmail.register_command('plugin.sieverules.delete', function(id) {
+					if (confirm(rcmail.gettext('filterdeleteconfirm','sieverules'))) {
+						var add_url = '';
+
+						var target = window;
+						if (rcmail.env.contentframe && window.frames && window.frames[rcmail.env.contentframe]) {
+							add_url = '&_framed=1';
+							target = window.frames[rcmail.env.contentframe];
+							rcube_find_object(rcmail.env.contentframe).style.visibility = 'inherit';
+						}
+
+						target.location.href = rcmail.env.comm_path+'&_action=plugin.sieverules.delete&_iid=' + rcmail.env.iid + add_url;
+						rcmail.enable_command('plugin.sieverules.delete', false);
+					}
+				}, false);
+
 				if (rcmail.env.action == 'plugin.sieverules.advanced') {
 					rcmail.register_command('plugin.sieverules.save', function() {
 						rcmail.gui_objects.editform.submit();
@@ -968,11 +1012,12 @@ $(document).ready(function() {
 					target.rcube_find_object('sieverulesrsdialog_add').style.display = 'none';
 					target.rcube_find_object('sieverulesrsdialog_edit').style.display = 'none';
 					target.rcube_find_object('sieverulesrsdialog_input').style.display = 'none';
-					target.rcube_find_object('sieverulesrsdialog_copyfrom').style.display = '';
+					//target.rcube_find_object('sieverulesrsdialog_copyfrom').style.display = '';
+					boxtitle = rcube_find_object('sieverulesrsdialog_copyfrom').innerHTML;
 					target.rcube_find_object('sieverulesrsdialog_select').style.display = '';
 					target.rcube_find_object('sieverulesrsdialog_action').value = props;
 
-					target.$('#sieverulesrsdialog').dialog({ width: 512, resizable: false, modal: true });
+					target.$('#sieverulesrsdialog').dialog({ title: boxtitle, width: 512, resizable: false, modal: true });
 				}, true);
 			}
 
@@ -998,12 +1043,8 @@ $(document).ready(function() {
 
 					rcmail.env.sieverules_rules++;
 					var tmp = $(newNode2).html().replace(/rowid/g, rcmail.env.sieverules_rules);
-					// remove nohtc class (IE6 fix)
-					tmp.replace(/class=["']?nohtc["']? /ig, "");
 					$(newNode2).html(tmp);
 					var tmp = $(newNode3).html().replace(/rowid/g, rcmail.env.sieverules_rules);
-					// remove nohtc class (IE6 fix)
-					tmp.replace(/class=["']?nohtc["']? /ig, "");
 					$(newNode3).html(tmp);
 
 					newNode1.style.display = "";
@@ -1048,8 +1089,6 @@ $(document).ready(function() {
 
 					rcmail.env.sieverules_actions++;
 					var tmp = $(newNode).html().replace(/rowid/g, rcmail.env.sieverules_actions);
-					// remove nohtc class (IE6 fix)
-					tmp.replace(/class=["']?nohtc["']? /ig, "");
 					$(newNode).html(tmp);
 
 					newNode.style.display = "";
@@ -1282,50 +1321,73 @@ $(document).ready(function() {
 					rcmail.gui_objects.editform.submit();
 				}, true);
 
-				rcmail.register_command('plugin.sieverules.delete', function(id) {
-					if (confirm(rcmail.gettext('filterdeleteconfirm','sieverules'))) {
-						var add_url = '';
-
-						var target = window;
-						if (rcmail.env.contentframe && window.frames && window.frames[rcmail.env.contentframe]) {
-							add_url = '&_framed=1';
-							target = window.frames[rcmail.env.contentframe];
-							rcube_find_object(rcmail.env.contentframe).style.visibility = 'inherit';
-						}
-
-						target.location.href = rcmail.env.comm_path+'&_action=plugin.sieverules.delete&_iid=' + rcmail.env.iid;
-					}
-				}, true);
-
 				rcmail.register_command('plugin.sieverules.vacation_sig', function(id) {
 					var obj = document.getElementById("rcmfd_sievevacfrom_" + id);
-					var input_message = $("#rcmfd_sievevacmag_" + id);
+					var is_html = ($("#rcmfd_sievevachtmlcb_" + id).is(':checked'));
 
 					if (!obj || !obj.options)
 						return false;
 
-					var cursor_pos, sig, id;
+					var sig, id;
 					var sig_separator = '-- ';
-					var message = input_message.val();
 
 					if (obj.options[0].value == 'auto' || obj.options[0].value == '')
 						id = obj.selectedIndex;
 					else
 						id = obj.selectedIndex + 1;
 
-					// add the signature string
-					if (rcmail.env.signatures && rcmail.env.signatures[id]) {
-						sig = rcmail.env.signatures[id]['text'];
-						sig = sig.replace(/\r\n/g, '\n');
+					if (is_html) {
+						var editor = tinyMCE.get("rcmfd_sievevacmag_" + id),
+						sigElem = editor.dom.get('_rc_sig');
 
-						if (!sig.match(/^--[ -]\n/))
-							sig = sig_separator + '\n' + sig;
+						// Append the signature as a div within the body
+						if (!sigElem) {
+							var body = editor.getBody(),
+							doc = editor.getDoc();
 
-						message = message.replace(/[\r\n]+$/, '');
-						message += '\n\n' + sig;
+							sigElem = doc.createElement('div');
+							sigElem.setAttribute('id', '_rc_sig');
+
+							if (bw.ie)  // add empty line before signature on IE
+								body.appendChild(doc.createElement('br'));
+
+							body.appendChild(sigElem);
+						}
+
+						if (rcmail.env.signatures[id]) {
+							if (rcmail.env.signatures[id].is_html) {
+								sig = rcmail.env.signatures[id].text;
+								if (!rcmail.env.signatures[id].plain_text.match(/^--[ -]\r?\n/m))
+									sig = sig_separator + '<br />' + sig;
+							}
+							else {
+								sig = rcmail.env.signatures[id].text;
+								if (!sig.match(/^--[ -]\r?\n/m))
+									sig = sig_separator + '\n' + sig;
+
+								sig = '<pre>' + sig + '</pre>';
+							}
+
+							sigElem.innerHTML = sig;
+						}
 					}
+					else {
+						var input_message = $("#rcmfd_sievevacmag_" + id);
+						var message = input_message.val();
 
-					input_message.val(message);
+						if (rcmail.env.signatures && rcmail.env.signatures[id]) {
+							sig = rcmail.env.signatures[id]['text'];
+							sig = sig.replace(/\r\n/g, '\n');
+
+							if (!sig.match(/^--[ -]\n/))
+								sig = sig_separator + '\n' + sig;
+
+							message = message.replace(/[\r\n]+$/, '');
+							message += '\n\n' + sig;
+						}
+
+						input_message.val(message);
+					}
 
 					return false;
 				}, false);
@@ -1357,6 +1419,9 @@ $(document).ready(function() {
 							var obj = document.getElementsByName('_datepart[]')[i];
 							var target_obj = $("input[name='_target[]']")[i];
 
+							$(target_obj).datepicker("destroy");
+							$(target_obj).unmask();
+
 							if (obj.value == 'date')
 								$(target_obj).datepicker({ dateFormat: 'yy-mm-dd' });
 							else if (obj.value == 'time')
