@@ -78,6 +78,7 @@ class sieverules extends rcube_plugin
 		$this->action = $rcmail->action;
 
 		$this->add_texts('localization/', array('filters', 'managefilters'));
+		$this->include_stylesheet($this->local_skin_path() . '/tabstyles.css');
 		$this->include_script('sieverules.js');
 
 		$this->register_action('plugin.sieverules', array($this, 'init_html'));
@@ -223,7 +224,7 @@ class sieverules extends rcube_plugin
 
 	function gen_list($attrib)
 	{
-		$this->api->output->add_label('sieverules.movingfilter', 'loading', 'sieverules.switchtoadveditor');
+		$this->api->output->add_label('sieverules.movingfilter', 'loading', 'sieverules.switchtoadveditor', 'sieverules.filterdeleteconfirm');
 		$this->api->output->add_gui_object('sieverules_list', 'sieverules-table');
 
 		$table = new html_table(array('id' => 'sieverules-table', 'class' => 'records-table', 'cellspacing' => '0', 'cols' => 2));
@@ -231,7 +232,6 @@ class sieverules extends rcube_plugin
 
 		if (sizeof($this->script) == 0) {
 			$table->add(array('colspan' => '2'), rep_specialchars_output($this->gettext('nosieverules')));
-			$table->add_row();
 		}
 		else foreach($this->script as $idx => $filter) {
 			$table->set_row_attribs(array('id' => 'rcmrow' . $idx));
@@ -249,7 +249,7 @@ class sieverules extends rcube_plugin
 			$table->add('control', $down_link . $up_link);
 		}
 
-		return html::tag('div', array('id' => 'sieverules-list-filters'), $table->show());
+		return html::tag('div', array('id' => 'sieverules-list-filters'), $table->show($attrib));
 	}
 
 	function gen_js_list()
@@ -273,13 +273,13 @@ class sieverules extends rcube_plugin
 			$down_link = $tmp_output->button(array('command' => 'plugin.sieverules.move', 'prop' => $dst, 'type' => 'link', 'class' => 'down_arrow', 'title' => 'sieverules.movedown', 'content' => ' '));
 			$down_link = str_replace("'", "\'", $down_link);
 
-			$this->api->output->command('sieverules_update_list', $idx == 0 ? 'add-first' : 'add', 'rcmrow' . $idx, Q($filter_name), $down_link, $up_link);
+			$this->api->output->command('sieverules_update_list', $idx == 0 ? 'add-first' : 'add', 'rcmrow' . $idx, JQ($filter_name), $down_link, $up_link);
 		}
 
 		$this->api->output->send();
 	}
 
-	function gen_examples()
+	function gen_examples($attrib)
 	{
 		if (sizeof($this->examples) > 0) {
 			$this->api->output->add_gui_object('sieverules_examples', 'sieverules-examples');
@@ -292,7 +292,7 @@ class sieverules extends rcube_plugin
 				$examples->add(null, Q($filter['name']));
 			}
 
-			return html::tag('div', array('id' => 'sieverules-list-examples'), $examples->show());
+			return html::tag('div', array('id' => 'sieverules-list-examples'), $examples->show($attrib));
 		}
 		else {
 			return '';
@@ -514,7 +514,7 @@ class sieverules extends rcube_plugin
 			'sieverules.headerbadchars', 'sieverules.noheadervalue', 'sieverules.sizewrongformat',
 			'sieverules.noredirect', 'sieverules.redirectaddresserror', 'sieverules.noreject', 'sieverules.vacnodays',
 			'sieverules.vacdayswrongformat', 'sieverules.vacnomsg', 'sieverules.notifynomethod', 'sieverules.missingfoldername',
-			'sieverules.notifynomsg', 'sieverules.filterdeleteconfirm', 'sieverules.ruledeleteconfirm',
+			'sieverules.notifynomsg', 'sieverules.ruledeleteconfirm',
 			'sieverules.actiondeleteconfirm', 'sieverules.notifyinvalidmethod', 'sieverules.nobodycontentpart',
 			'sieverules.badoperator','sieverules.baddateformat','sieverules.badtimeformat','sieverules.vactoexp_err','editorwarning');
 
@@ -535,10 +535,8 @@ class sieverules extends rcube_plugin
 			$this->api->output->set_env('iid', $iid);
 			$example = false;
 
-			if (isset($this->script[$iid])) {
-				$this->api->output->add_script("if (parent.". JS_OBJECT_NAME .".sieverules_examples) parent.". JS_OBJECT_NAME .".sieverules_examples.clear_selection();");
-				$this->api->output->add_script("parent.". JS_OBJECT_NAME .".sieverules_list.highlight_row(".$iid.");");
-			}
+			if (isset($this->script[$iid]))
+				$this->api->output->add_script("parent.". JS_OBJECT_NAME .".sieverules_ready('".$iid."');");
 		}
 
 		if (sizeof($rcmail->config->get('sieverules_predefined_rules')) > 0) {
@@ -609,9 +607,9 @@ class sieverules extends rcube_plugin
 		$out .= html::tag('fieldset', null, html::tag('legend', null, Q($this->gettext('messagesrules')))
 				. Q((!$rcmail->config->get('sieverules_use_elsif', true)) ? $this->gettext('sieveruleexp_stop'): $this->gettext('sieveruleexp')) . "<br /><br />"
 				. $join_type . "<br /><br />"
-				. $rules_table->show());
+				. $rules_table->show($attrib));
 
-		$rcmail->imap_connect();
+		$rcmail->storage_connect();
 		$actions_table = new html_table(array('id' => 'actions-table', 'class' => 'records-table', 'cellspacing' => '0', 'cols' => 3));
 		$actions_table = $this->_action_row($ext, $actions_table, 'rowid', null, $attrib, $example);
 
@@ -621,10 +619,11 @@ class sieverules extends rcube_plugin
 			$actions_table = $this->_action_row($ext, $actions_table, $idx, $actions, $attrib, $example);
 
 		$this->api->output->set_env('sieverules_actions', $actions_table->size());
+		$this->api->output->set_env('sieverules_htmleditor', $rcmail->config->get('htmleditor'));
 
 		$out .= html::tag('fieldset', null, html::tag('legend', null, Q($this->gettext('messagesactions')))
 				. Q($this->gettext('sieveactexp')). "<br /><br />"
-				. $actions_table->show());
+				. $actions_table->show($attrib));
 
 		$out .= $form_end;
 
@@ -850,16 +849,16 @@ class sieverules extends rcube_plugin
 					case 'fileinto_copy':
 						$folder = $this->_strip_val($folders[$idx]);
 						$rcmail = rcmail::get_instance();
-						$rcmail->imap_connect();
+						$rcmail->storage_connect();
 						$script['actions'][$i]['create'] = false;
 						if ($folder == '@@newfolder') {
 							$script['actions'][$i]['create'] = true;
 							$folder = $this->_strip_val($customfolders[$idx]);
-							$folder = $rcmail->config->get('sieverules_include_imap_root', true) ? $rcmail->imap->mod_mailbox($folder, 'IN') : $folder;
+							$folder = $rcmail->config->get('sieverules_include_imap_root', true) ? $rcmail->storage->mod_folder($folder, 'IN') : $folder;
 						}
-						$script['actions'][$i]['target'] = $rcmail->config->get('sieverules_include_imap_root', true) ? $folder : $rcmail->imap->mod_mailbox($folder);
+						$script['actions'][$i]['target'] = $rcmail->config->get('sieverules_include_imap_root', true) ? $folder : $rcmail->storage->mod_folder($folder);
 						if ($rcmail->config->get('sieverules_folder_delimiter', false))
-							$script['actions'][$i]['target'] = str_replace($rcmail->imap->get_hierarchy_delimiter(), $rcmail->config->get('sieverules_folder_delimiter'), $script['actions'][$i]['target']);
+							$script['actions'][$i]['target'] = str_replace($rcmail->storage->get_hierarchy_delimiter(), $rcmail->config->get('sieverules_folder_delimiter'), $script['actions'][$i]['target']);
 						break;
 					case 'redirect':
 					case 'redirect_copy':
@@ -1001,8 +1000,8 @@ class sieverules extends rcube_plugin
 		}
 		else {
 			// go to sieverules page
-			rcmail_overwrite_action('plugin.sieverules.edit');
-			$this->action = 'plugin.sieverules.edit';
+			rcmail_overwrite_action('plugin.sieverules');
+			$this->action = 'plugin.sieverules';
 			$this->init_html();
 		}
 	}
@@ -1266,12 +1265,9 @@ class sieverules extends rcube_plugin
 	private function _rule_row($ext, $rules_table, $rule, $predefined_rules, $attrib)
 	{
 		$rcmail = rcmail::get_instance();
-		$imgclass = null;
 
-		if (!isset($rule)) {
+		if (!isset($rule))
 			$rules_table->set_row_attribs(array('style' => 'display: none;'));
-			$imgclass = 'nohtc';
-		}
 
 		if (in_array('regex', $ext) || in_array('relational', $ext) || in_array('subaddress', $ext))
 			$this->operators['filteradvoptions'] = 'advoptions';
@@ -1487,7 +1483,7 @@ class sieverules extends rcube_plugin
 		$input_test = new html_hiddenfield(array('name' => '_test[]', 'value' => $test));
 		$rules_table->add('selheader', $select_header->show($selheader) . $input_test->show());
 
-		$help_button = html::img(array('class' => $imgclass, 'src' => $attrib['helpicon'], 'alt' => $this->gettext('sieveruleheaders'), 'border' => 0, 'style' => 'margin-left: 4px;'));
+		$help_button = html::img(array('src' => $attrib['helpicon'], 'alt' => $this->gettext('sieveruleheaders'), 'border' => 0, 'style' => 'margin-left: 4px;'));
 		$help_button = html::a(array('name' => '_headerhlp', 'href' => "#", 'onclick' => 'return '. JS_OBJECT_NAME .'.sieverules_xheaders(this);', 'title' => $this->gettext('sieveruleheaders'), 'style' => $header_style), $help_button);
 
 		$input_header = new html_inputfield(array('name' => '_header[]', 'style' => $header_style, 'class' => 'short'));
@@ -1579,7 +1575,6 @@ class sieverules extends rcube_plugin
 
 		$headers_table = new html_table(array('class' => 'records-table', 'cellspacing' => '0', 'cols' => 4));
 		$headers_table->add(array('colspan' => 4, 'style' => 'white-space: normal;'), Q($this->gettext('sieveheadershlp')));
-		$headers_table->add_row();
 
 		$col1 = '';
 		$col2 = '';
@@ -1610,13 +1605,11 @@ class sieverules extends rcube_plugin
 
 		$rules_table->set_row_attribs(array('style' => 'display: none;'));
 		$rules_table->add(array('colspan' => 5), $headers_table->show());
-		$rules_table->add_row();
 
 		$advanced_table = new html_table(array('class' => 'records-table', 'cellspacing' => '0', 'cols' => 2));
 		$advanced_table->add(array('colspan' => 2, 'style' => 'white-space: normal;'), Q($this->gettext('advancedoptions')));
-		$advanced_table->add_row();
 
-		$help_button = html::img(array('class' => $imgclass, 'src' => $attrib['helpicon'], 'alt' => $this->gettext('contentpart'), 'border' => 0, 'style' => 'margin-left: 4px;'));
+		$help_button = html::img(array('src' => $attrib['helpicon'], 'alt' => $this->gettext('contentpart'), 'border' => 0, 'style' => 'margin-left: 4px;'));
 		$help_button = html::a(array('href' => "#", 'onclick' => 'return '. JS_OBJECT_NAME .'.sieverules_help(this, ' . $advanced_table->size() . ');', 'title' => $this->gettext('contentpart')), $help_button);
 
 		$field_id = 'rcmfd_advcontentpart_'. $rowid;
@@ -1627,7 +1620,6 @@ class sieverules extends rcube_plugin
 
 		$advanced_table->set_row_attribs(array('class' => 'advhelp', 'style' => 'display: none;'));
 		$advanced_table->add(array('colspan' => 2, 'class' => 'vacdaysexp'), $this->gettext('contentpartexp'));
-		$advanced_table->add_row();
 
 		$field_id = 'rcmfd_advoperator_'. $rowid;
 		$select_advop = new html_select(array('id' => $field_id, 'name' => "_advoperator[]", 'onchange' => JS_OBJECT_NAME . '.sieverules_rule_advop_select(this)'));
@@ -1698,7 +1690,6 @@ class sieverules extends rcube_plugin
 		if (!($showadvanced && $predefined == -1))
 			$rules_table->set_row_attribs(array('style' => 'display: none;'));
 		$rules_table->add(array('colspan' => 5), $advanced_table->show());
-		$rules_table->add_row();
 
 		return $rules_table;
 	}
@@ -1707,12 +1698,9 @@ class sieverules extends rcube_plugin
 	{
 		$rcmail = rcmail::get_instance();
 		static $a_mailboxes;
-		$imgclass = null;
 
-		if (!isset($action)) {
+		if (!isset($action))
 			$actions_table->set_row_attribs(array('style' => 'display: none;'));
-			$imgclass = 'nohtc';
-		}
 
 		$help_icon = html::img(array('src' => $attrib['helpicon'], 'alt' => $this->gettext('messagehelp'), 'border' => 0));
 
@@ -1787,10 +1775,10 @@ class sieverules extends rcube_plugin
 
 		if ($action['type'] == 'fileinto' || $action['type'] == 'fileinto_copy') {
 			$method = $action['type'];
-			$folder = $rcmail->config->get('sieverules_include_imap_root', true) ? $action['target'] : $rcmail->imap->mod_mailbox($action['target']);
+			$folder = $rcmail->config->get('sieverules_include_imap_root', true) ? $action['target'] : $rcmail->storage->mod_folder($action['target'], 'IN');
 
 			if ($rcmail->config->get('sieverules_folder_delimiter', false))
-				$folder = str_replace($rcmail->imap->get_hierarchy_delimiter(), $rcmail->config->get('sieverules_folder_delimiter'), $folder);
+				$folder = str_replace($rcmail->storage->get_hierarchy_delimiter(), $rcmail->config->get('sieverules_folder_delimiter'), $folder);
 		}
 		elseif ($action['type'] == 'reject' || $action['type'] == 'ereject') {
 			$method = $action['type'];
@@ -1808,6 +1796,18 @@ class sieverules extends rcube_plugin
 			$msg = $action['msg'];
 			$htmlmsg = $action['htmlmsg'] ? '1' : '';
 			$charset = $action['charset'];
+
+			if ($htmlmsg == '1' && $rcmail->config->get('htmleditor') == '0') {
+				$h2t = new html2text($msg, false, true, 0);
+				$msg = $h2t->get_text();
+				$htmlmsg = '';
+			}
+			elseif ($htmlmsg == '' && $rcmail->config->get('htmleditor') == '1') {
+				$msg = htmlspecialchars($msg);
+				$msg = nl2br($msg);
+				$htmlmsg = '1';
+			}
+
 			if (!$example)
 				$this->force_vacto = false;
 
@@ -1901,7 +1901,6 @@ class sieverules extends rcube_plugin
 
 			$vacs_table->set_row_attribs(array('class' => 'advhelp', 'style' => 'display: none;'));
 			$vacs_table->add(array('colspan' => 3, 'class' => 'vacdaysexp'), $this->gettext('vactoexp'));
-			$vacs_table->add_row();
 		}
 		else {
 			$field_id = 'rcmfd_sievevacfrom_'. $rowid;
@@ -1923,7 +1922,6 @@ class sieverules extends rcube_plugin
 			$vacs_table->add(null, $help_button);
 			$vacs_table->set_row_attribs(array('class' => 'advhelp', 'style' => 'display: none;'));
 			$vacs_table->add(array('colspan' => 3, 'class' => 'vacdaysexp'), $this->gettext('vactoexp') . '<br /><br />' . $this->gettext('vactoexp_adv'));
-			$vacs_table->add_row();
 		}
 
 		$field_id = 'rcmfd_sievevacdays_'. $rowid;
@@ -1935,7 +1933,6 @@ class sieverules extends rcube_plugin
 
 		$vacs_table->set_row_attribs(array('style' => 'display: none;'));
 		$vacs_table->add(array('colspan' => 3, 'class' => 'vacdaysexp'), $this->gettext('vacdaysexp'));
-		$vacs_table->add_row();
 
 		$field_id = 'rcmfd_sievevachandle_'. $rowid;
 		$input_handle = new html_inputfield(array('id' => $field_id, 'name' => '_handle[]', 'class' => 'short'));
@@ -1947,13 +1944,11 @@ class sieverules extends rcube_plugin
 
 		$vacs_table->set_row_attribs(array('class' => 'advhelp', 'style' => 'display: none;'));
 		$vacs_table->add(array('colspan' => 3, 'class' => 'vacdaysexp'), $this->gettext('vachandleexp'));
-		$vacs_table->add_row();
 
 		$field_id = 'rcmfd_sievevacsubject_'. $rowid;
 		$input_subject = new html_inputfield(array('id' => $field_id, 'name' => '_subject[]'));
 		$vacs_table->add(null, html::label($field_id, Q($this->gettext('subject'))));
 		$vacs_table->add(array('colspan' => 2), $input_subject->show($subject));
-		$vacs_table->add_row();
 
 		if (in_array('variables', $ext)) {
 			$field_id = 'rcmfd_sievevacsubject_orig_'. $rowid;
@@ -1961,22 +1956,19 @@ class sieverules extends rcube_plugin
 			$input_vacosubj = new html_hiddenfield(array('id' => 'rcmfd_sievevactoh_'. $rowid, 'name' => '_orig_subject[]', 'value' => $origsubject));
 			$vacs_table->add(null, '&nbsp;');
 			$vacs_table->add(array('colspan' => 2), $input_origsubject->show($origsubject) . "&nbsp;" . html::label($field_id, Q($this->gettext('sieveorigsubj'))) . $input_vacosubj->show());
-			$vacs_table->add_row();
 		}
 
 		$field_id = 'rcmfd_sievevacmag_'. $rowid;
 		$input_msg = new html_textarea(array('id' => $field_id, 'name' => '_msg[]', 'rows' => '8', 'cols' => '40', 'class' => $htmlmsg == 1 ? 'mce_editor' : ''));
-		$input_html = new html_checkbox(array('onclick' => JS_OBJECT_NAME . '.sieverules_toggle_vac_html(this, '. $rowid .', \'' . $field_id .'\');', 'value' => '1', 'class' => 'checkbox'));
+		$input_html = new html_checkbox(array('id' => 'rcmfd_sievevachtmlcb_'. $rowid, 'onclick' => JS_OBJECT_NAME . '.sieverules_toggle_vac_html(this, '. $rowid .', \'' . $field_id .'\');', 'value' => '1', 'class' => 'checkbox'));
 		$input_htmlhd = new html_hiddenfield(array('id' => 'rcmfd_sievevachtmlhd_'. $rowid, 'name' => '_htmlmsg[]', 'value' => $htmlmsg));
 		$vacs_table->add('msg', html::label($field_id, Q($this->gettext('message'))));
-		$vacs_table->add(array('colspan' => 2), $input_msg->show($msg) . html::tag('div', null, $input_html->show($htmlmsg) . "&nbsp;" . html::label('rcmfd_sievevachtml_' . $rowid, Q($this->gettext('htmlmessage'))) . $input_htmlhd->show()));
-		$vacs_table->add_row();
+		$vacs_table->add(array('colspan' => 2), $input_msg->show($msg) . html::tag('div', in_array('htmleditor', $rcmail->config->get('dont_override')) ? array('style' => 'display: none;') : null, $input_html->show($htmlmsg) . "&nbsp;" . html::label('rcmfd_sievevachtml_' . $rowid, Q($this->gettext('htmlmessage')))) . $input_htmlhd->show());
 
 		$field_id = 'rcmfd_sievecharset_'. $rowid;
 		$vacs_table->set_row_attribs(array('class' => 'advanced', 'style' => $vacadvstyle));
 		$vacs_table->add(null, html::label($field_id, Q($this->gettext('charset'))));
 		$vacs_table->add(array('colspan' => 2), $this->_charset_selector(array('id' => $field_id, 'name' => '_charset[]'), $charset));
-		$vacs_table->add_row();
 
 		$input_advopts = new html_checkbox(array('id' => 'vadvopts' . $rowid, 'name' => '_vadv_opts[]', 'onclick' => JS_OBJECT_NAME . '.sieverules_show_adv(this);', 'value' => '1', 'class' => 'checkbox'));
 		$vacs_table->add(array('colspan' => '3', 'style' => 'text-align: right'), html::label('vadvopts' . $rowid, Q($this->gettext('advancedoptions'))) . $input_advopts->show($vacshowadv));
@@ -1995,24 +1987,20 @@ class sieverules extends rcube_plugin
 			$notify_table->set_row_attribs(array('class' => 'advanced', 'style' => $noteadvstyle));
 			$notify_table->add(null, html::label($field_id, Q($this->gettext('sievefrom'))));
 			$notify_table->add(array('colspan' => 2), $select_id->show($nfrom));
-			$notify_table->add_row();
 		}
 
 		$field_id = 'rcmfd_nmethod_'. $rowid;
 		$input_method = new html_inputfield(array('id' => $field_id, 'name' => '_nmethod[]'));
 		$notify_table->add(null, html::label($field_id, Q($this->gettext('method'))));
 		$notify_table->add(array('colspan' => 2), $input_method->show($nmethod));
-		$notify_table->add_row();
 
 		$field_id = 'rcmfd_noption_'. $rowid;
 		$input_method = new html_inputfield(array('id' => $field_id, 'name' => '_noption[]'));
 		$notify_table->add(null, html::label($field_id, Q($this->gettext('options'))));
 		$notify_table->add(array('colspan' => 2), $input_method->show($noptions));
-		$notify_table->add_row();
 
 		$notify_table->set_row_attribs(array('style' => 'display: none;'));
 		$notify_table->add(array('colspan' => 3, 'class' => 'vacdaysexp'), $this->gettext('nmethodexp'));
-		$notify_table->add_row();
 
 		$field_id = 'rcmfd_nimpt_'. $rowid;
 		$input_importance = new html_radiobutton(array('id' => $field_id . '_none', 'name' => '_notify_radio_' . $rowid, 'value' => 'none', 'onclick' => JS_OBJECT_NAME . '.sieverules_notify_impt(this, '. $rowid .')', 'class' => 'radio'));
@@ -2028,13 +2016,11 @@ class sieverules extends rcube_plugin
 		$notify_table->set_row_attribs(array('class' => 'advanced', 'style' => $noteadvstyle));
 		$notify_table->add(null, Q($this->gettext('flag')));
 		$notify_table->add(array('colspan' => 2), $importance_show . $input_importance->show($nimpt));
-		$notify_table->add_row();
 
 		$field_id = 'rcmfd_nmsg_'. $rowid;
 		$input_msg = new html_inputfield(array('id' => $field_id, 'name' => '_nmsg[]'));
 		$notify_table->add(null, html::label($field_id, Q($this->gettext('message'))));
 		$notify_table->add(array('colspan' => 2), $input_msg->show($nmsg));
-		$notify_table->add_row();
 
 		if (in_array('enotify', $ext)) {
 			$input_advopts = new html_checkbox(array('id' => 'nadvopts' . $rowid, 'name' => '_nadv_opts[]', 'onclick' => JS_OBJECT_NAME . '.sieverules_show_adv(this);', 'value' => '1', 'class' => 'checkbox'));
@@ -2042,17 +2028,17 @@ class sieverules extends rcube_plugin
 		}
 
 		// get mailbox list
-		$mbox_name = $rcmail->imap->get_mailbox_name();
+		$mbox_name = $rcmail->storage->get_folder();
 
 		// build the folders tree
 		if (empty($a_mailboxes)) {
 			// get mailbox list
 			if ($rcmail->config->get('sieverules_fileinto_options', 0) > 0)
-				$a_folders = $rcmail->imap->list_unsubscribed();
+				$a_folders = $rcmail->storage->list_folders();
 			else
-				$a_folders = $rcmail->imap->list_mailboxes();
+				$a_folders = $rcmail->storage->list_folders_subscribed();
 
-			$delimiter = $rcmail->imap->get_hierarchy_delimiter();
+			$delimiter = $rcmail->storage->get_hierarchy_delimiter();
 			$a_mailboxes = array();
 
 			foreach ($a_folders as $ifolder) {
@@ -2073,8 +2059,8 @@ class sieverules extends rcube_plugin
 		rcmail_render_folder_tree_select($a_mailboxes, $mbox_name, 100, $input_folderlist, false);
 
 		$show_customfolder = 'display: none;';
-		if ($rcmail->config->get('sieverules_fileinto_options', 0) == 2 && !$rcmail->imap->mailbox_exists($folder)) {
-			$customfolder = $rcmail->imap->mod_mailbox($folder);
+		if ($rcmail->config->get('sieverules_fileinto_options', 0) == 2 && !$rcmail->storage->folder_exists($folder)) {
+			$customfolder = $rcmail->storage->mod_folder($folder);
 			$folder = '@@newfolder';
 			$show_customfolder = '';
 		}
@@ -2147,7 +2133,7 @@ class sieverules extends rcube_plugin
 
 	private function _mbox_encode($text, $encoding)
 	{
-		return rcube_charset_convert($text, 'UTF7-IMAP', $encoding);
+		return rcube_charset::convert($text, 'UTF7-IMAP', $encoding);
 	}
 }
 
